sphinxjp.themes.gopher
Author: https://github.com/tell-k
Description: A sphinx theme for generate gotalk style presentation. #sphinxjp

# Search

Please activate JavaScript to enable the search functionality.

From here you can search these documents. Enter your search words into the box below and click "search". Note that the search function will automatically search for all of the words. Pages containing fewer words won't appear in the result list.

Use the left and right arrow keys or click the left and right edges of the page to navigate between slides.
(Press 'H' or navigate to hide this message.)